Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Options ¶
type Options struct {
// RPCServer is the address of the RPC server.
RPCServer string `json:"rpcserver" mapstructure:"rpcserver"`
// ClientCA represents the file path of the client certificate authority.
ClientCA string `json:"client-ca-file" mapstructure:"client-cat-file"`
// GenericServerOptions holds the options for running a generic server.
GenericServerOptions *genericOptions.ServerRunOptions `json:"server" mapstructure:"server"`
// InsecureServing options for running the server without TLS.
InsecureServing *genericOptions.InsecureServingOptions `json:"insecure" mapstructure:"insecure"`
// SecureServing options for running the server with TLS.
SecureServing *genericOptions.SecureServingOptions `json:"secure" mapstructure:"secure"`
// RedisOptions specifies the options for connecting to Redis.
RedisOptions *genericOptions.RedisOptions `json:"redis" mapstructure:"redis"`
// FeatureOptions holds configurations for specific features.
FeatureOptions *genericOptions.FeatureOptions `json:"feature" mapstructure:"featrue"`
// Log holds the logging configuration.
Log *log.Options `json:"log" mapstucture:"log"`
}
Options struct defines the configuration options for the server.
func NewOptions ¶
func NewOptions() *Options
NewOptions initializes a new Options object with default values.
func (*Options) Flags ¶
func (o *Options) Flags() (fss flag.NamedFlagSets)
Flags defines and returns a set of flags for configuring the server.
Click to show internal directories.
Click to hide internal directories.